%define module_name ipt_NETFLOW
%define dkms_package dkms-%{module_name}
%define upstream_name ipt-netflow

Name:		%{module_name}
Version:	2.6
Release:	%mkrel 4
Summary:	DKMS-ready module for ipt_netflow, an iptables modules
Group:		Development/Kernel
License:	GPLv3
Source:		https://github.com/aabc/ipt-netflow/releases/%{upstream_name}-%{version}.tar.gz
# Disable searching for iptables sources, not used anyway
Patch0:		ipt_NETFLOW-2.4-nosrc.patch

BuildRequires:	pkgconfig(libiptc)
BuildRequires:	pkgconfig(xtables)
BuildRequires:	kernel-desktop-devel-latest

%description
ipt_netflow is very fast and effective Netflow exporting module for Linux kernel.
This is netfilter/iptables module adding support for NETFLOW target.

%package -n %{dkms_package}
Summary:	DKMS-ready module for ipt_netflow, an iptables modules
Provides:	kmod(ipt_NETFLOW.ko) = %{version}
Requires(pre):	dkms
Requires(post):	dkms
BuildArch:	noarch

%description -n %{dkms_package}
ipt_netflow is very fast and effective Netflow exporting module for Linux kernel.
This is netfilter/iptables module adding support for NETFLOW target.

This package provides the %{module_name} kernel module(s).

%package -n iptables-NETFLOW
Summary:	The NETFLOW library which will be loaded by iptables when NETFLOW rules are processed
Requires:	kmod(ipt_NETFLOW.ko)

%description -n iptables-NETFLOW
The NETFLOW library which will be loaded by iptables when NETFLOW rules are processed.

%prep
%setup -q -n %{upstream_name}-%{version}
%autopatch -p1

%build
%set_build_flags
# set kernel-devel dir
KPKG=$(rpm -q --requires kernel-desktop-devel-latest | grep kernel-desktop-devel)
KDIR=$(rpm -ql $KPKG | grep '/usr/src/[^/]*$')
./configure --kdir=$KDIR
%make_build libipt_NETFLOW.so LIBS=-lxtables
%make_build compat_def.h

%install
# Install the library
make DESTDIR=%{buildroot} linstall

# generate version.h
./version.sh --define > version.h
# Install the sources of the module
mkdir -p %{buildroot}/usr/src/
mkdir -p %{buildroot}/usr/src/%{module_name}-%{version}-%{release}
cp -a  ../ipt-netflow-%{version}/*.{c,h} ../ipt-netflow-%{version}/Makefile %{buildroot}/usr/src/%{module_name}-%{version}-%{release}

cat > %{buildroot}/usr/src/%{module_name}-%{version}-%{release}/dkms.conf <<EOF

PACKAGE_VERSION="%{version}-%{release}"

#Items below here should not have to change with each driver version
PACKAGE_NAME="%{module_name}"
CLEAN="make clean"
BUILT_MODULE_NAME[0]="%{module_name}"
DEST_MODULE_LOCATION[0]="/kernel/net/netfilter/"
AUTOINSTALL=yes
EOF

%post -n %{dkms_package}
dkms add -m %{module_name} -v %{version}-%{release} --rpm_safe_upgrade
dkms build -m %{module_name} -v %{version}-%{release} --rpm_safe_upgrade
dkms install -m %{module_name} -v %{version}-%{release} --rpm_safe_upgrade

%preun -n %{dkms_package}
dkms remove -m %{module_name} -v %{version}-%{release} --rpm_safe_upgrade --all || :

%files -n %{dkms_package}
/usr/src/%{module_name}-%{version}-%{release}

%files -n iptables-NETFLOW
%{_libdir}/iptables/libipt_NETFLOW.so
%{_libdir}/iptables/libip6t_NETFLOW.so


%changelog
* Mon Jul 07 2025 umeabot <umeabot> 2.6-4.mga10
+ Revision: 2248774
- Mageia 10 Mass Rebuild

* Tue Mar 18 2025 papoteur <papoteur> 2.6-3.mga10
+ Revision: 2166256
- fix library path

* Tue Mar 29 2022 umeabot <umeabot> 2.6-2.mga9
+ Revision: 1831621
- Mageia 9 Mass Rebuild

* Mon Aug 09 2021 luigiwalser <luigiwalser> 2.6-1.mga9
+ Revision: 1740817
- 2.6

* Sun Aug 23 2020 luigiwalser <luigiwalser> 2.5.1-3.mga8
+ Revision: 1618156
- fix language errors making compat_def.h (mga#26844)

* Thu Aug 20 2020 luigiwalser <luigiwalser> 2.5.1-2.mga8
+ Revision: 1617028
- generate missing compat_def.h

* Wed Aug 19 2020 luigiwalser <luigiwalser> 2.5.1-1.mga8
+ Revision: 1615586
- 2.5.1 (kernel 5.8 support)

* Tue Feb 18 2020 umeabot <umeabot> 2.4-2.mga8
+ Revision: 1539920
- Mageia 8 Mass Rebuild
+ wally <wally>
- replace deprecated %%setup_compile_flags

* Fri Dec 13 2019 tmb <tmb> 2.4-1.mga8
+ Revision: 1466686
- update to 2.4 (mga#25858)

* Sat Sep 08 2018 tmb <tmb> 2.3-1.mga7
+ Revision: 1257745
- BR kernel-desktop-devel-latest
- update to 2.3
  * rediff P0
  * drop obsolete P1-P4
- fix module version
- update filelists

* Fri Jun 22 2018 wally <wally> 1.8-10.mga7
+ Revision: 1238792
- build using mageia compile time flags

* Mon Feb 08 2016 umeabot <umeabot> 1.8-9.mga6
+ Revision: 948175
- Mageia 6 Mass Rebuild

* Wed Oct 15 2014 umeabot <umeabot> 1.8-8.mga5
+ Revision: 739068
- Second Mageia 5 Mass Rebuild

* Wed Sep 24 2014 tmb <tmb> 1.8-7.mga5
+ Revision: 724118
- adapt to new kmod provides

* Tue Sep 16 2014 umeabot <umeabot> 1.8-6.mga5
+ Revision: 680548
- Mageia 5 Mass Rebuild

* Tue Feb 11 2014 pterjan <pterjan> 1.8-5.mga5
+ Revision: 589455
- Update patch for kernel 3.11

* Mon Oct 21 2013 umeabot <umeabot> 1.8-4.mga4
+ Revision: 540829
- Mageia 4 Mass Rebuild

* Thu Oct 10 2013 pterjan <pterjan> 1.8-3.mga4
+ Revision: 494358
- Copy only needed files, to avoid getting the built .so in the dkms

* Sat Oct 05 2013 pterjan <pterjan> 1.8-2.mga4
+ Revision: 492016
- Fix package name
- Fix scriptlets
- Include release in dkms version, else dkms gets upset on update
- Patch for recent kernels

* Sat Oct 05 2013 pterjan <pterjan> 1.8-1.mga4
+ Revision: 492006
- imported package ipt_NETFLOW


* Tue Sep 10 2013 FranÃois Crosnier <crox53> 1.8-1.mga2
- Initial version of the package
